@@ -1,7 +1,7 @@
 #!/usr/bin/env bash
 # netdata
 # real-time performance and health monitoring, done right!
-# (C) 2017 Costa Tsaousis <costa@tsaousis.gr>
+# (C) 2023 Netdata Inc.
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 # Exit code: 0 - Success
@@ -118,7 +118,7 @@ if ! command -v openssl >/dev/null 2>&1 ; then
 fi
 
 # shellcheck disable=SC2050
-if [ "detect" = "no" ]; then
+if [ "yes" = "no" ]; then
     echo >&2 "This agent was built with --disable-cloud and cannot be claimed"
     exit 3
 fi
@@ -152,7 +152,7 @@ gen_id() {
     local id
 
     if command -v uuidgen > /dev/null 2>&1; then
-        id="$(uuidgen)"
+        id="$(uuidgen | tr '[:upper:]' '[:lower:]')"
     elif [ -r /proc/sys/kernel/random/uuid ]; then
         id="$(cat /proc/sys/kernel/random/uuid)"
     else
@@ -175,7 +175,7 @@ elif [ -f "${MACHINE_GUID_FILE}" ]; then
         echo >&2 "netdata.public.unique.id is not readable. Please make sure you have rights to read it (Filename: ${MACHINE_GUID_FILE})."
         exit 18
 else
-        if mkdir -p "${MACHINE_GUID_FILE%/*}" && /bin/echo -n "$(gen_id)" > "${MACHINE_GUID_FILE}"; then
+        if mkdir -p "${MACHINE_GUID_FILE%/*}" && echo -n "$(gen_id)" > "${MACHINE_GUID_FILE}"; then
                 ID="$(cat "${MACHINE_GUID_FILE}")"
                 MGUID=$ID
         else
@@ -194,24 +194,37 @@ if [ -r "${CLAIMING_DIR}/rooms" ]; then
         ROOMS="$(cat "${CLAIMING_DIR}/rooms")"
 fi
 
+variable_to_set=
 for arg in "$@"
 do
-        case $arg in
-                -token=*) TOKEN=${arg:7} ;;
-                -url=*) [ -n "${arg:5}" ] && URL_BASE=${arg:5} ;;
-                -id=*) ID=${arg:4} ;;
-                -rooms=*) ROOMS=${arg:7} ;;
-                -hostname=*) HOSTNAME=${arg:10} ;;
-                -verbose) VERBOSE=1 ;;
-                -insecure) INSECURE=1 ;;
-                -proxy=*) PROXY=${arg:7} ;;
-                -noproxy) NOPROXY=yes ;;
-                -noreload) RELOAD=0 ;;
-                -user=*) NETDATA_USER=${arg:6} ;;
-                -daemon-not-running) NETDATA_RUNNING=0 ;;
-                *)  echo >&2 "Unknown argument ${arg}"
-                    exit 1 ;;
-        esac
+        if [ -z "$variable_to_set" ]; then
+              case $arg in
+                      --claim-token) variable_to_set="TOKEN" ;;
+                      --claim-rooms) variable_to_set="ROOMS" ;;
+                      --claim-url) variable_to_set="URL_BASE" ;;
+                      -token=*) TOKEN=${arg:7} ;;
+                      -url=*) [ -n "${arg:5}" ] && URL_BASE=${arg:5} ;;
+                      -id=*) ID=$(echo "${arg:4}" | tr '[:upper:]' '[:lower:]');;
+                      -rooms=*) ROOMS=${arg:7} ;;
+                      -hostname=*) HOSTNAME=${arg:10} ;;
+                      -verbose) VERBOSE=1 ;;
+                      -insecure) INSECURE=1 ;;
+                      -proxy=*) PROXY=${arg:7} ;;
+                      -noproxy) NOPROXY=yes ;;
+                      -noreload) RELOAD=0 ;;
+                      -user=*) NETDATA_USER=${arg:6} ;;
+                      -daemon-not-running) NETDATA_RUNNING=0 ;;
+                      *)  echo >&2 "Unknown argument ${arg}"
+                          exit 1 ;;
+              esac
+        else
+              case "$variable_to_set" in
+                      TOKEN) TOKEN="$arg" ;;
+                      ROOMS) ROOMS="$arg" ;;
+                      URL_BASE) URL_BASE="$arg" ;;
+              esac
+              variable_to_set=
+        fi
         shift 1
 done
 
@@ -296,7 +309,7 @@ if [ "${URLTOOL}" = "curl" ] ; then
                 URLCOMMAND="${URLCOMMAND} -x \"${PROXY}\""
         fi
 else
-        URLCOMMAND="wget -T 15 -O -  -q --save-headers --content-on-error=on --method=PUT \
+        URLCOMMAND="wget -T 15 -O -  -q --server-response --content-on-error=on --method=PUT \
         --body-file=\"${CLAIMING_DIR}/tmpin.txt\""
         if [ "${NOPROXY}" = "yes" ] ; then
                 URLCOMMAND="${URLCOMMAND} --no-proxy"
@@ -326,7 +339,11 @@ if [ "${VERBOSE}" == 1 ]; then
 fi
 
 attempt_contact () {
-        eval "${URLCOMMAND} \"${TARGET_URL}\"" >"${CLAIMING_DIR}/tmpout.txt"
+        if [ "${URLTOOL}" = "curl" ] ; then
+                eval "${URLCOMMAND} \"${TARGET_URL}\"" >"${CLAIMING_DIR}/tmpout.txt"
+        else
+                eval "${URLCOMMAND} \"${TARGET_URL}\"" >"${CLAIMING_DIR}/tmpout.txt" 2>&1
+        fi
         URLCOMMAND_EXIT_CODE=$?
         if [ "${URLTOOL}" = "wget" ] && [ "${URLCOMMAND_EXIT_CODE}" -eq 8 ] ; then
         # We consider the server issuing an error response a successful attempt at communicating
@@ -396,37 +413,33 @@ if [ "${HTTP_STATUS_CODE}" = "204" ] || [ "${ERROR_KEY}" = "ErrAlreadyClaimed" ]
 [global]
   enabled = yes
   cloud base url = $URL_BASE
+${PROXY:+  proxy = $PROXY}
 HERE_DOC
         if [ "$EUID" == "0" ]; then
-            chown -R "${NETDATA_USER}:${NETDATA_USER}" ${CLAIMING_DIR} || (echo >&2 "Claiming failed"; set -e; exit 2)
+            chown -R "${NETDATA_USER}:${NETDATA_USER}" "${CLAIMING_DIR}" || (echo >&2 "Claiming failed"; set -e; exit 2)
         fi
         if [ "${RELOAD}" == "0" ] ; then
             exit $EXIT_CODE
         fi
 
-        if [ -z "${PROXY}" ]; then
-           PROXYMSG=""
-        else
-           PROXYMSG="You have attempted to claim this node through a proxy - please update your the proxy setting in your netdata.conf to ${PROXY}. "
-        fi
         # Update cloud.conf in the agent memory
         /usr/bin/netdatacli write-config 'cloud|global|enabled|yes' && \
         /usr/bin/netdatacli write-config "cloud|global|cloud base url|$URL_BASE" && \
         /usr/bin/netdatacli reload-claiming-state && \
         if [ "${HTTP_STATUS_CODE}" = "204" ] ; then
-                echo >&2 "${PROXYMSG}Node was successfully claimed."
+                echo >&2 "Node was successfully claimed."
         else
                 echo >&2 "The agent cloud base url is set to the url provided."
                 echo >&2 "The cloud may have different credentials already registered for this agent ID and it cannot be reclaimed under different credentials for security reasons. If you are unable to connect use -id=\$(uuidgen) to overwrite this agent ID with a fresh value if the original credentials cannot be restored."
-                echo >&2 "${PROXYMSG}Failed to claim node with the following error message:\"${ERROR_MESSAGES[$EXIT_CODE]}\""
+                echo >&2 "Failed to claim node with the following error message:\"${ERROR_MESSAGES[$EXIT_CODE]}\""
         fi && exit $EXIT_CODE
 
         if [ "${ERROR_KEY}" = "ErrAlreadyClaimed" ] ; then
                 echo >&2 "The cloud may have different credentials already registered for this agent ID and it cannot be reclaimed under different credentials for security reasons. If you are unable to connect use -id=\$(uuidgen) to overwrite this agent ID with a fresh value if the original credentials cannot be restored."
-                echo >&2 "${PROXYMSG}Failed to claim node with the following error message:\"${ERROR_MESSAGES[$EXIT_CODE]}\""
+                echo >&2 "Failed to claim node with the following error message:\"${ERROR_MESSAGES[$EXIT_CODE]}\""
                 exit $EXIT_CODE
         fi
-        echo >&2 "${PROXYMSG}The claim was successful but the agent could not be notified ($?)- it requires a restart to connect to the cloud."
+        echo >&2 "The claim was successful but the agent could not be notified ($?)- it requires a restart to connect to the cloud."
         [ "$NETDATA_RUNNING" -eq 0 ] && exit 0 || exit 5
 fi
 
